@@ -23,7 +23,7 @@ class ProjectIdentifiedByPhoneFromTicketMessage extends AbstractMessage
         return $this->data['project'];
     }
 
-    public function setProject(string $project): self
+    public function setProject(?string $project): self
     {
         $this->data['project'] = $project;
         return $this;
@@ -34,7 +34,7 @@ class ProjectIdentifiedByPhoneFromTicketMessage extends AbstractMessage
         return $this->data['ticket'];
     }
 
-    public function setTicket(string $ticket): self
+    public function setTicket(?string $ticket): self
     {
         $this->data['ticket'] = $ticket;
         return $this;
